@@ -340,6 +340,9 @@ enum Command {
 
     #[structopt(about = "Save default configuration file", display_order(2000))]
     SaveConfig,
+
+    #[structopt(about = " Check for updates to statehub utility", display_order(3000))]
+    SelfUpdate,
 }
 
 impl Cli {
@@ -479,6 +482,7 @@ impl Cli {
             Command::ListPods => statehub.list_pods().await,
             Command::ListRegions { zone } => statehub.list_regions(zone).await,
             Command::SaveConfig => statehub.save_config().await,
+            Command::SelfUpdate => statehub.self_update().await,
         }
     }
 }
@@ -494,8 +498,11 @@ pub(crate) struct StateHub {
 }
 
 impl StateHub {
+    const PLATFORM: &'static str = env!("VERGEN_CARGO_TARGET_TRIPLE");
+    const VERSION: &'static str = env!("VERGEN_BUILD_SEMVER");
+
     fn new(config: Config, json: bool, verbose: bool) -> Self {
-        let api = api::Api::new(config.api(), config.token());
+        let api = api::Api::new(config.api(), v0::VERSION, config.token());
         let stdout = Term::stdout();
         let stderr = Term::stderr();
         let theme = theme::SimpleTheme;
@@ -890,6 +897,22 @@ impl StateHub {
         })
     }
 
+    async fn self_update(&self) -> anyhow::Result<()> {
+        if let Some((current, latest)) = self.check_for_update_helper().await {
+            self.inform(format_args!(
+                "Newer version {} is available (you have {})",
+                latest, current
+            ))
+            .context("Checking for latest release")?;
+
+            if current < latest {
+                self.update_helper(latest).await?;
+            }
+        }
+
+        Ok(())
+    }
+
     fn confirm(&self, prompt: impl Into<String>) -> bool {
         let theme = self.theme();
         Confirm::with_theme(theme)
